/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.application;

import java.util.Map;
import java.util.TreeMap;

import javax.annotation.PostConstruct;
import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;

/**
 * This bean is an application-wide bean, responsible for storing the possible themes (look and feels) available within the program. It is not possible to import new
 * themes during runtime.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@ManagedBean
@ApplicationScoped
public final class ThemeSwitcherBean {

	/**
	 * A map containing all available themes.
	 */
	private final Map<String, String> themes = new TreeMap<String, String>();

	/**
	 * Creates a new instance of this class.
	 */
	public ThemeSwitcherBean() {
		// No code necessary
	}

	/**
	 * Returns the available themes.
	 * 
	 * @return A map containing the user readable names of the themes as a key and the actual theme-names as the corresponding value.
	 */
	public Map<String, String> getThemes() {
		return this.themes;
	}

	/**
	 * Initializes the bean. If one wants to add new themes to the program, this is the right place.
	 */
	@PostConstruct
	public void init() {
		this.themes.put("Aristo", "aristo");
		this.themes.put("Black-Tie", "black-tie");
		this.themes.put("Blitzer", "blitzer");
		this.themes.put("Bluesky", "bluesky");
		this.themes.put("Casablanca", "casablanca");
		this.themes.put("Cupertino", "cupertino");
		this.themes.put("Dark-Hive", "dark-hive");
		this.themes.put("Dot-Luv", "dot-luv");
		this.themes.put("Eggplant", "eggplant");
		this.themes.put("Excite-Bike", "excite-bike");
		this.themes.put("Flick", "flick");
		this.themes.put("Glass-X", "glass-x");
		this.themes.put("Hot-Sneaks", "hot-sneaks");
		this.themes.put("Humanity", "humanity");
		this.themes.put("Le-Frog", "le-frog");
		this.themes.put("Midnight", "midnight");
		this.themes.put("Mint-Choc", "mint-choc");
		this.themes.put("Overcast", "overcast");
		this.themes.put("Pepper-Grinder", "pepper-grinder");
		this.themes.put("Redmond", "redmond");
		this.themes.put("Rocket", "rocket");
		this.themes.put("Sam", "sam");
		this.themes.put("Smoothness", "smoothness");
		this.themes.put("South-Street", "south-street");
		this.themes.put("Start", "start");
		this.themes.put("Sunny", "sunny");
		this.themes.put("Swanky-Purse", "swanky-purse");
		this.themes.put("Trontastic", "trontastic");
		this.themes.put("UI-Darkness", "ui-darkness");
		this.themes.put("UI-Lightness", "ui-lightness");
		this.themes.put("Vader", "vader");
	}
}
