/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.session;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;

/**
 * This bean contains the project of the current (session) user for the analysis view work space.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@ManagedBean
@SessionScoped
public class CurrentAnalysisViewWorkSpaceProjectBean {

	/**
	 * This is the page used for the redirecting during setting the current project of the user.
	 */
	private static final String PAGE_ANALYSIS_VIEW_WORK_SPACE = "AnalysisViewWorkSpace.xhtml";
	/**
	 * This is the page used for the redirecting during closing the work space.
	 */
	private static final String PAGE_PROJECT_OVERVIEW = "ProjectOverview.xhtml";
	/**
	 * This is the name of the stored project. It can be used as an identifier within the FS-Manager
	 */
	private String projectName;

	/**
	 * Creates a new instance of this class.
	 */
	public CurrentAnalysisViewWorkSpaceProjectBean() {
		// No code necessary
	}

	/**
	 * This method sets the project stored within this bean and returns the new page for the navigation.
	 * 
	 * @param projectName
	 *            The name of the project.
	 * @return The name of the page for the analysis view work space.
	 */
	public String setProject(final String projectName) {
		this.projectName = projectName;

		return CurrentAnalysisViewWorkSpaceProjectBean.PAGE_ANALYSIS_VIEW_WORK_SPACE;
	}

	/**
	 * This method delivers the project name stored in this bean.
	 * 
	 * @return The project name for this user.
	 */
	public String getProjectName() {
		return this.projectName;
	}

	/**
	 * This method clears the bean. In other words: The stored project is set to null and it will return the page of the project overview for navigation purposes.
	 * 
	 * @return The name of the page of the project overview.
	 */
	public String clearProject() {
		this.projectName = null;

		return CurrentAnalysisViewWorkSpaceProjectBean.PAGE_PROJECT_OVERVIEW;
	}
}
